@@ -1,7 +1,6 @@
 import json
 from enum import Enum
 import requests
-from typing import Optional
 
 
 class SolanaNetwork(Enum):
@@ -64,7 +63,7 @@ class TheBlockchainAPIResource:
             r = requests.request(
                 request_method.value,
                 url=self.__url + endpoint,
-                data=json.dumps(payload),
+                params=payload,
                 headers=headers
             )
         else:
